@@ -1,6 +1,6 @@
 """Plugin package for Pyaud."""
-from . import modules
+from . import _plugins
 from ._environ import environ
 from ._version import __version__
 
-__all__ = ["__version__", "modules", "environ"]
+__all__ = ["__version__", "environ"]
