@@ -5,7 +5,8 @@ pyaud.environ
 Set up the environment variables for the current project.
 """
 # pylint: disable=invalid-name,too-many-public-methods
-import typing as _t
+from __future__ import annotations
+
 from pathlib import Path as _Path
 
 import pyaud as _pyaud
@@ -13,15 +14,18 @@ from environs import Env as _Env
 
 
 class _Environ(_Env):
-    def __getattribute__(self, item: str) -> _t.Any:
-        """Roughly equivalent to inheriting ``pyaud.environ``'s type."""
-        try:
-            return object.__getattribute__(self, item)
-        except AttributeError:
-            return getattr(_pyaud.environ, item)
+    @property
+    def PREFIX(self) -> str:
+        """Prefix for variables which may turn out to be ambiguous."""
+        return "PYAUD_"
 
     @property
-    def GITHUB_REPOSITORY_OWNER(self) -> _t.Optional[str]:
+    def REPO(self) -> str:
+        """The name of the repo that this is being run in."""
+        return _Path.cwd().name
+
+    @property
+    def GITHUB_REPOSITORY_OWNER(self) -> str | None:
         """Env variable which may exist in a GitHub workflow."""
         return self.str("GITHUB_REPOSITORY_OWNER", default=None)
 
@@ -64,30 +68,30 @@ class _Environ(_Env):
             )
 
     @property
-    def GH_NAME(self) -> _t.Optional[str]:
+    def GH_NAME(self) -> str | None:
         """Username of GH user."""
         with self.prefixed(self.PREFIX):
             return self.str("GH_NAME", default=self.GITHUB_REPOSITORY_OWNER)
 
     @property
-    def GH_EMAIL(self) -> _t.Optional[str]:
+    def GH_EMAIL(self) -> str | None:
         """Email of GH user."""
         with self.prefixed(self.PREFIX):
             return self.str("GH_EMAIL", default=None)
 
     @property
-    def GH_TOKEN(self) -> _t.Optional[str]:
+    def GH_TOKEN(self) -> str | None:
         """Authentication token of GH user."""
         with self.prefixed(self.PREFIX):
             return self.str("GH_TOKEN", default=None)
 
     @property
-    def CODECOV_TOKEN(self) -> _t.Optional[str]:
+    def CODECOV_TOKEN(self) -> str | None:
         """Authentication token for codecov.io."""
         return self.str("CODECOV_TOKEN", default=None)
 
     @property
-    def GH_REMOTE(self) -> _t.Optional[str]:
+    def GH_REMOTE(self) -> str | None:
         """URL of repository remote."""
         default = None
         if all([self.GH_NAME, self.GH_EMAIL, self.GH_TOKEN]):
@@ -144,14 +148,6 @@ class _Environ(_Env):
                 "README", default=_Path("README.rst")
             )
 
-    @property
-    def README_MD(self) -> _Path:
-        """Location of the README.md."""
-        with self.prefixed(self.PREFIX):
-            return _Path.cwd() / self.path(
-                "README", default=_Path("README.md")
-            )
-
     @property
     def TESTS(self) -> _Path:
         """Location of tests."""
